==> 1.0.9.tar.gz: example/lib/interstitial.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:fusionsdk/fusion_ad_sdk.dart';
import 'dart:io';

class InterstitialPage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomPadding: true,
      primary: true,
      appBar: AppBar(),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            MaterialButton(
                color: Colors.blue,
                textColor: Colors.white,
                onPressed: () {
                  var codeId;
                  if(Platform.isAndroid) {
                    codeId = "89810603429855232";
                  }
                  if(Platform.isIOS) {
                    codeId = "196014123429920768";
                  }
                  FusionAdSdk.loadInterstitialAd(
                    codeId,
                    onAdLoad: () {
                      print("Interad onAdLoad");
                    },
                    onAdShow: () {
                      print("Interad onAdShow");
                    },
                    onAdClick: () {
                      print("Interad onAdClick");
                    },
                    onAdClose: () {
                      print("Interad onAdClose");
                    },
                    onAdError: (int code, String message) {
                      print("Interad onAdError :  $code  $message");
                    },
                  );
                },
                child: Text("加载插屏广告")),
          ],
        ),
      ),
    );
  }
}

==> 1.1.5.tar.gz: example/lib/interstitial.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:fusionsdk/fusion_ad_sdk.dart';
import 'dart:io';

class InterstitialPage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: true,
      primary: true,
      appBar: AppBar(),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            MaterialButton(
                color: Colors.blue,
                textColor: Colors.white,
                onPressed: () {
                  var codeId;
                  if(Platform.isAndroid) {
                    codeId = "89810603429855232";
                  }
                  if(Platform.isIOS) {
                    codeId = "196014123429920768";
                  }
                  FusionAdSdk.loadInterstitialAd(
                    codeId,
                    onAdLoad: () {
                      print("Interad onAdLoad");
                    },
                    onAdShow: () {
                      print("Interad onAdShow");
                    },
                    onAdClick: () {
                      print("Interad onAdClick");
                    },
                    onAdClose: () {
                      print("Interad onAdClose");
                    },
                    onAdError: (int code, String message) {
                      print("Interad onAdError :  $code  $message");
                    },
                  );
                },
                child: Text("加载插屏广告")),
          ],
        ),
      ),
    );
  }
}
